import time
import contextlib
import os
from importlib.metadata import version


@contextlib.contextmanager
def timing(tag, enabled=True):
    if enabled:
        t = time.time()
    try:
        yield
    finally:
        if enabled:
            t1 = time.time()
            print(f"{tag}: {(t1 - t)*1000:.2f}ms")


static_directory = os.path.join(os.path.expanduser("~"), ".hyperdiv", "static")


def strip_path_suffix(path, components_to_strip=0):
    while components_to_strip > 0:
        path = os.path.split(path)[0]
        components_to_strip -= 1
    return path


def get_version():
    # Note: This assumes that hyperdiv is installed in the current
    # virtualenv or distribution. This assumption holds when
    # developing locally with poetry, because `poetry install`
    # installs the local project into the virtualenv, using a `.pth`
    # alias.
    return version("hyperdiv")
