from .styled_element import StyledElement
from ..core.element import Prop
from .icon import inline_icon_html, Icons


def label_join(label):
    return " ".join(
        [
            inline_icon_html(chunk) if type(chunk) is Icons else str(chunk)
            for chunk in label
        ]
    )


def parse_label(label):
    if isinstance(label, Icons):
        label = inline_icon_html(label)
    return label


class LabelProp(Prop):
    """
    Accepts either text or an icon.
    """

    def parse(self, value):
        return parse_label(value)


class LabelElement(StyledElement):
    label = LabelProp("")

    def args_to_props(self, *label, **props):
        """
        If `*label` is provided, the `label` prop is set to the string
        resulting from concatenating all the `*label` pieces with `"
        "`. If a `label` is also provided in `**props`, `*label` wins.
        """
        if label:
            props["label"] = label_join(label)
        return props
