from .icon import Icons, inline_icon_html
from .label_element import LabelElement, LabelProp
from markdown import markdown as parse_markdown
from textwrap import dedent as dedent_text


def parse_hd_markdown(markdown_str):
    markdown_str = dedent_text(markdown_str)
    return parse_markdown(markdown_str, extensions=["fenced_code"])


class MarkdownProp(LabelProp):
    """
    Accepts markdown text.
    """

    def parse(self, value):
        return parse_hd_markdown(value)


class text(LabelElement):
    # Override label prop to parse the value as markdown
    label = MarkdownProp("")

    # Identify icons in the args and convert to html
    # and escape any given HTML
    def args_to_props(self, *label, **props):
        """
        If `*label` is given, the label pieces are concatenated by `" "`
        and used to update the `label` prop. The `*label` pieces can
        be text or icons. For example:

        ```py
        hd.text(
            "I ate",
            hd.Icons.BaconSolid,
            "and eggs."
        )
        ```
        """
        if len(label) > 0:
            label = list(label)
            for index, arg in enumerate(label):
                if isinstance(arg, Icons):
                    label[index] = inline_icon_html(arg)
        return super().args_to_props(*label, **props)


def link(url, name=None):
    if name is None:
        name = url
    return text(f'<a href="{url}">{name}</a>')


def anchor(name):
    return text(f'<a tabindex="-1" name="{name}"></a>')
