from ..core.element import DynamicProp
from .form_input import FormInput
from .styled_element import StyledElement
from .theme import theme_prop
from .props import StrProp, BoolProp


class DynamicValueProp(DynamicProp):
    def _register_change(self, new_value):
        in_user_code = self.context.in_user_code()
        if in_user_code:
            if new_value != self.value:
                self.parent_element.echo = False
        else:
            self.parent_element.reset_prop("echo")

        super()._register_change(new_value)


class text_input(StyledElement, FormInput):
    value = StrProp("", dynamic_class=DynamicValueProp)
    echo = BoolProp(True)  # TODO: Read-only
    placeholder = StrProp("")

    # Override StyledElement
    padding = theme_prop("input_padding")
    background_color = theme_prop("surface_color")
    border = theme_prop("input_border")
    font_color = theme_prop("font_color")
    font_family = theme_prop("font_family")

    @property
    def is_empty(self):
        return self.value == ""
